# The 0MQ messaging kernel RPM .spec file
#
# Common usage:
#   rpmbuild -ba --clean "$(rpm --eval='%{_specdir}')/zeromq-4.2.1-centos6.spec"
#
# Possible additional switches:
#   --without makejobslimit (don't limit number of make jobs to run simultaneously)
#   --without todayepoch (don't set "Epoch" field to the current YYYYMMDD, leave it unspecified)
#   --without ownsourcedir (don't use separate "zeromq-x.x.x/" folder inside "rpmbuild/SOURCES/")
#   --with selftests (perform self-testing after successful build)
#   --with gitmaster (use source tarball generated from Git "master" branch)
#   --with gitvernum (use version number generated from 'git describe' command)
#   --define 'SysTempDir value' (default is /var/tmp)
#   --define 'GitRepoDir value' (default is $HOME/Sources/CentOS/libzmq.git)
#   --with ccache (use a fast C/C++ compiler cache during build)

# Acceptable build conditions

%bcond_with makejobslimit
%bcond_with todayepoch
%bcond_with ownsourcedir

# disable self-testing by default
%bcond_with selftests

%bcond_with gitmaster
%bcond_with gitvernum

%bcond_with ccache

# Version numbers

%define VerMajor       4
%define VerMinor       2
%define PatchLevel     1
%define Revision       2

%define ShortVersion   %{VerMajor}.%{VerMinor}
%define LongVersion    %{ShortVersion}.%{PatchLevel}

# Other globals and defines

%define PackageName    zeromq

%global CurDate        %(date +%Y%m%d)
%define DistroTag      %{?centos:.centos%{?centos_ver}%{!?centos_ver:%{centos}}}%{!?centos:%{?dist}}

%if %{with makejobslimit}
%define _smp_mflags    --jobs=1
%else
%define GetNumMakeJobs \
	HalfOfCPUs=`bc <<< "$(/usr/bin/getconf _NPROCESSORS_ONLN) / 2"`; \
	if [ $HalfOfCPUs -ge 1 ]; then echo $HalfOfCPUs; else echo 1; fi \
%{nil}
%global NumMakeJobs    %(%{GetNumMakeJobs})
%define _smp_mflags    --jobs=%{NumMakeJobs} --load-average=2.0
%endif

%if %{with ownsourcedir}
%define _sourcedir     %{_topdir}/SOURCES/%{PackageName}-%{LongVersion}
%endif

%if %{with gitmaster}
%define SourceName     %{PackageName}-%{LongVersion}-git
%else
%define SourceName     %{PackageName}-%{LongVersion}
%endif

%define VersionFile    %{_sourcedir}/%{PackageName}-pkg-version.txt

%{!?SysTempDir: %global SysTempDir /var/tmp}
%{!?GitRepoDir: %global GitRepoDir %{getenv:HOME}/Sources/CentOS/libzmq.git}

%if %{with gitvernum}
%define GitDescribe    $(git -C %{GitRepoDir} describe --long HEAD | cut -c 2- 2>/dev/null)
%define MakeGitVersion \
	if [ -d %{GitRepoDir} ]; then \
		IFS=.- read GitMajor GitMinor GitPatchLevel GitNumCommits GitHashSuffix <<< "%{GitDescribe}" && \
		echo $GitMajor.$GitMinor.$GitPatchLevel.$GitNumCommits.$GitHashSuffix 2>/dev/null \
	elif [ -f %{VersionFile} ]; then \
		echo $(cat %{VersionFile}) \
	else \
		echo %{LongVersion}.git \
	fi \
%{nil}
%global GitVersion     %(%{MakeGitVersion})
%else
%global GitVersion     %{nil}
%endif

%define GetCCacheVersion \
	CCachePkgVersion=$(rpm -q --qf '%{version}' ccache) \
	if [ $? -ne 0 ]; then \
		CCachePkgVersion="0.0.0" \
	fi \
	echo $CCachePkgVersion \
%{nil}
%global CCacheVersion  %(%{GetCCacheVersion})

%define TestCCache32 \
	IFS=. read CCacheMajor CCacheMinor CCachePatchLevel <<< "%{CCacheVersion}"; \
	if [ $CCacheMajor -eq 3 -a $CCacheMinor -ge 2 ]; then echo YES; else echo NO; fi \
%{nil}
%global HasCCache      %(%{TestCCache32})

# Header

Name: %{PackageName}

%if %{with gitvernum}
Version: %{GitVersion}
%else
Version: %{LongVersion}
%endif
Release: %{Revision}%{DistroTag}
%if %{with todayepoch}
Epoch: %{CurDate}
%endif

Summary: Software library for fast, message-based applications
Group: System Environment/Libraries
License: LGPLv3+ with exceptions

URL: http://zeromq.org/

Vendor: Zarezky.spb.ru RPM repository, http://zarezky.spb.ru/yumrepo/
Packager: Elijah Zarezky <elijah@zarezky.spb.ru>

# Sources

%if %{with gitmaster}
Source0: %{SourceName}.tar.gz
Source1: ChangeLog
%else
Source0: https://github.com/zeromq/libzmq/releases/download/v%{version}/%{SourceName}.tar.gz
%endif

%if %{with gitvernum}
Source2: %{VersionFile}
%endif

# Patches

# Directory for the (fake) install step

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

# Build requirements

BuildRequires: glib2-devel >= 2.28.8
BuildRequires: krb5-devel >= 1.10
BuildRequires: libuuid-devel >= 2.17.2
BuildRequires: libsodium-devel >= 1.0.6
BuildRequires: openpgm-devel >= 5.1.118

BuildRequires: chrpath >= 0.13

# Run-time requirements

Requires: glib2 >= 2.28.8
Requires: libuuid >= 2.17.2
Requires: libsodium >= 1.0.6
Requires: openpgm >= 5.1.118

# Virtual package names

Provides: %{name}3 = %{version}-%{release}
Obsoletes: %{name}3 < 3.2.4

# Description

%description
The 0MQ lightweight messaging kernel is a library which extends the
standard socket interfaces with features traditionally provided by
specialized messaging middle-ware products. 0MQ sockets provide an
abstraction of asynchronous message queues, multiple messaging
patterns, message filtering (subscriptions), seamless access to
multiple transport protocols and more.

This package contains the ZeroMQ shared library for versions 4.x.

# Subpackages

%package devel
Summary: Development files for %{name}
Group: Development/Libraries
Requires: %{name}%{?_isa} = %{?epoch:%{epoch}:}%{version}-%{release}
Provides: %{name}3-devel = %{version}-%{release}
Obsoletes: %{name}3-devel < 3.2.4

%description devel
The %{name}-devel package contains libraries and header files for
developing applications that use %{name} 4.x.

# Build scripts

%prep
%if %{with gitmaster}
if [ -d %{GitRepoDir} ]; then
	%{__rm} -f %{_sourcedir}/%{SourceName}.tar.gz
	pushd %{GitRepoDir}
	git archive --format=tar.gz --prefix=%{SourceName}/ --output=%{_sourcedir}/%{SourceName}.tar.gz HEAD
	git log --stat > %{_sourcedir}/ChangeLog
	popd
%if %{with gitvernum}
	echo %{GitVersion} > %{VersionFile}
%endif
fi
%{__rm} -rf %{SourceName}
%{__tar} -xzf %{_sourcedir}/%{SourceName}.tar.gz
%{__cp} %{SOURCE1} %{SourceName}/
%setup -q -n %{SourceName} -T -D
./autogen.sh
%{__chmod} -x branding.bmp installer.ico README.cygwin.md
%else
%setup -q -n %{SourceName}
%endif

# fix ChangeLog enconding
%{_bindir}/iconv -f iso8859-1 -t utf-8 ChangeLog > ChangeLog.utf8 && %{__mv} -f ChangeLog.utf8 ChangeLog

# don't turn warnings into errors
%{__sed} -i -e "s/libzmq_werror=\"yes\"/libzmq_werror=\"no\"/g" configure

%build
%if %{with ccache} && "%{HasCCache}" == "YES"
export CC="ccache gcc"
export CXX="ccache g++"
%endif

export CFLAGS="%{optflags} -w"
export CXXFLAGS="%{optflags} -w"

%configure \
	--enable-silent-rules \
	--enable-static \
	--enable-shared \
	--enable-curve-keygen \
	--enable-curve \
	--with-docs \
	--with-libgssapi_krb5 \
	--with-libsodium \
	--with-pgm
%{__make} %{?_smp_mflags}

%if %{with gitmaster}
doxygen Doxygen.cfg
%endif

%check
%if %{with selftests}
%{__make} check
%endif

%install
%{__rm} -rf %{buildroot}

%{__make} install DESTDIR=%{buildroot} INSTALL="%{__install} -p"
chrpath --delete %{buildroot}%{_bindir}/curve_keygen
%{__rm} %{buildroot}%{_libdir}/*.la

%clean
%{__rm} -rf %{buildroot}

# Install/uninstall scripts

%pretrans

%pre

%post -p /sbin/ldconfig

%preun

%postun -p /sbin/ldconfig

%posttrans

# Files to install

%files
%defattr(-, root, root, -)
%doc AUTHORS COPYING COPYING.LESSER NEWS
%if %{with gitmaster}
%doc README.*
%endif
%{_bindir}/curve_keygen
%{_libdir}/libzmq.so.*

%files devel
%defattr(-, root, root, -)
%doc ChangeLog
%if %{with gitmaster}
%doc doxygen/html
%endif
%{_includedir}/zmq*.h
%{_libdir}/libzmq.so
%{_libdir}/*.a
%{_libdir}/pkgconfig/libzmq.pc
%{_mandir}/man3/zmq*.3*
%{_mandir}/man7/zmq*.7*

# Changes in the package

%changelog
* Tue Jan 03 2017 Elijah Zarezky <elijah@zarezky.spb.ru> - 4.2.1-1
- Updated to the latest stable version 4.2.1.
- Built using "--with gitmaster --with gitvernum".

* Wed Nov 23 2016 Elijah Zarezky <elijah@zarezky.spb.ru> - 4.2.0-1
- Updated to the latest stable version 4.2.0.
- Built using "--with gitmaster --with gitvernum".

* Thu Oct 13 2016 Elijah Zarezky <elijah@zarezky.spb.ru> - 4.1.5-1
- Updated to the latest stable version 4.1.5.

* Fri Dec 04 2015 Elijah Zarezky <elijah@zarezky.spb.ru> - 4.1.3-1
- Initial package.
- Built using "--with selftests".
